@@ -1,6 +1,9 @@
+#!/usr/bin/env python3
+# coding: utf-8
+
 import argparse
 
-from .pymirror import PyMirror, FirefoxInterrupt, pids
+from .__init__ import __version__
 
 
 class CustomHelpFormatter(argparse.HelpFormatter):
@@ -9,7 +12,7 @@ class CustomHelpFormatter(argparse.HelpFormatter):
 
     def _format_action_invocation(self, action):
         if not action.option_strings or action.nargs == 0:
-            return super()._format_action_invocation(action)
+            return super()._format_action_invocation(action)  # noqa
         default = self._get_default_metavar_for_optional(action)
         args_string = self._format_args(action, default)
         return ', '.join(action.option_strings) + ' ' + args_string
@@ -19,17 +22,19 @@ def fmt(prog):
     return CustomHelpFormatter(prog)
 
 
-def main(**kwargs):
-
-    parser = argparse.ArgumentParser(prog='pymirror',
-                                     formatter_class=fmt,
+def cli():
+    # noinspection PyTypeChecker
+    parser = argparse.ArgumentParser(prog='pymirror', formatter_class=fmt,
                                      add_help=False)
     parser.add_argument('-h',
                         '--help',
                         action='help',
                         default=argparse.SUPPRESS,
                         help='Show this help message and exit')
-    parser.add_argument('-i', '--input', help='Path to the input file/folder', required=True)
+    parser.add_argument('-i',
+                        '--input',
+                        help='Path to the input file/folder',
+                        required=True)
     parser.add_argument('-s',
                         '--style',
                         help='Output style (default: lines)',
@@ -58,20 +63,28 @@ def main(**kwargs):
         help='Check the status of the remote servers (default: False)',
         action='store_false',
         default=False)
+    parser.add_argument(
+        '--debug',
+        help='Debug',
+        action='store_true',
+        default=False)
     parser.add_argument(
         '-l',
         '--log',
         help='Show logs and save it to a file (default: False)',
         action='store_true',
         default=False)
+    parser.add_argument(
+        '-e',
+        '--experimental',
+        help='Generate even more links (experimental) (default: False)',
+        action='store_true',
+        default=False)
+    parser.add_argument('-v',
+                        '--version',
+                        action='version',
+                        version=f'%(prog)s {__version__}')
+
 
     args = parser.parse_args()
-
-    mirror = PyMirror().uploader(args)
-
-
-if __name__ == '__main__':
-    try:
-        main()
-    except Exception:
-        FirefoxInterrupt.firefoxInterrupt(pids)
+    return args
